==> jc-1.4.0.tar.gz: javax/rmi/PortableRemoteObject.h <==
// public class javax.rmi.PortableRemoteObject

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d746a431d093b671 javax_rmi_PortableRemoteObject

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_rmi_PortableRemoteObject_H_
#define _JC_javax_rmi_PortableRemoteObject_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_rmi_Remote$object;
struct _jc_javax_rmi_CORBA_PortableRemoteObjectDelegate$object;

// Typedefs
typedef struct _jc_javax_rmi_PortableRemoteObject$sub_refs	_jc_javax_rmi_PortableRemoteObject$sub_refs;
typedef struct _jc_javax_rmi_PortableRemoteObject$sub_nonrefs	_jc_javax_rmi_PortableRemoteObject$sub_nonrefs;
typedef struct _jc_javax_rmi_PortableRemoteObject$refs	_jc_javax_rmi_PortableRemoteObject$refs;
typedef struct _jc_javax_rmi_PortableRemoteObject$nonrefs	_jc_javax_rmi_PortableRemoteObject$nonrefs;
typedef struct _jc_javax_rmi_PortableRemoteObject$object	_jc_javax_rmi_PortableRemoteObject$object;

typedef struct _jc_javax_rmi_PortableRemoteObject$fields_struct	_jc_javax_rmi_PortableRemoteObject$fields_struct;
typedef const struct _jc_javax_rmi_PortableRemoteObject$vmethods	_jc_javax_rmi_PortableRemoteObject$vmethods;
typedef const struct _jc_javax_rmi_PortableRemoteObject$vtable	_jc_javax_rmi_PortableRemoteObject$vtable;
typedef const struct _jc_javax_rmi_PortableRemoteObject$vtype	_jc_javax_rmi_PortableRemoteObject$vtype;

// Class fields structure
struct _jc_javax_rmi_PortableRemoteObject$fields_struct {
	struct _jc_object	*delegate;
};
extern _jc_javax_rmi_PortableRemoteObject$fields_struct _jc_javax_rmi_PortableRemoteObject$class_fields;

// Constructors
extern void _jc_javax_rmi_PortableRemoteObject$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_rmi_PortableRemoteObject$object *);

// Static methods
extern void _jc_javax_rmi_PortableRemoteObject$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern void _jc_javax_rmi_PortableRemoteObject$method$connect$64cce43a3a8f81df(_jc_env *, struct _jc_object *, struct _jc_object *);
extern void _jc_javax_rmi_PortableRemoteObject$method$exportObject$f24f2fffff6dde7d(_jc_env *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_javax_rmi_PortableRemoteObject$method$narrow$3c78d1e45f465b3b(_jc_env *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Class$object *);
extern struct _jc_object *_jc_javax_rmi_PortableRemoteObject$method$toStub$eb510defe3584b97(_jc_env *, struct _jc_object *);
extern void _jc_javax_rmi_PortableRemoteObject$method$unexportObject$be7fa0efab735c7e(_jc_env *, struct _jc_object *);

// Virtual methods structure
struct _jc_javax_rmi_PortableRemoteObject$vmethods {
};

// Vtable
struct _jc_javax_rmi_PortableRemoteObject$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_rmi_PortableRemoteObject$vmethods	javax_rmi_PortableRemoteObject;
};

// Vtype
struct _jc_javax_rmi_PortableRemoteObject$vtype {
	_jc_type			type;
	_jc_javax_rmi_PortableRemoteObject$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_rmi_PortableRemoteObject$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_rmi_PortableRemoteObject$refs {
    _jc_javax_rmi_PortableRemoteObject$sub_refs	javax_rmi_PortableRemoteObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_rmi_PortableRemoteObject$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_rmi_PortableRemoteObject$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_rmi_PortableRemoteObject$sub_nonrefs	javax_rmi_PortableRemoteObject;
};

// Object instance structure
struct _jc_javax_rmi_PortableRemoteObject$object {
	_jc_javax_rmi_PortableRemoteObject$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_rmi_PortableRemoteObject$vtype	*vtype;
	_jc_javax_rmi_PortableRemoteObject$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_rmi_PortableRemoteObject$vtype _jc_javax_rmi_PortableRemoteObject$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_rmi_PortableRemoteObject, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_rmi_PortableRemoteObject$class_object;

#endif	/* _JC_javax_rmi_PortableRemoteObject_H_ */

==> jc-1.4.6.tar.gz: javax/rmi/PortableRemoteObject.h <==
// public class javax.rmi.PortableRemoteObject

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d746a431d093b671 javax_rmi_PortableRemoteObject

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_rmi_PortableRemoteObject_H_
#define _JC_javax_rmi_PortableRemoteObject_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_rmi_Remote$object;
struct _jc_javax_rmi_CORBA_PortableRemoteObjectDelegate$object;

// Typedefs
typedef struct _jc_javax_rmi_PortableRemoteObject$sub_refs	_jc_javax_rmi_PortableRemoteObject$sub_refs;
typedef struct _jc_javax_rmi_PortableRemoteObject$sub_nonrefs	_jc_javax_rmi_PortableRemoteObject$sub_nonrefs;
typedef struct _jc_javax_rmi_PortableRemoteObject$refs	_jc_javax_rmi_PortableRemoteObject$refs;
typedef struct _jc_javax_rmi_PortableRemoteObject$nonrefs	_jc_javax_rmi_PortableRemoteObject$nonrefs;
typedef struct _jc_javax_rmi_PortableRemoteObject$object	_jc_javax_rmi_PortableRemoteObject$object;

typedef struct _jc_javax_rmi_PortableRemoteObject$fields_struct	_jc_javax_rmi_PortableRemoteObject$fields_struct;
typedef const struct _jc_javax_rmi_PortableRemoteObject$vmethods	_jc_javax_rmi_PortableRemoteObject$vmethods;
typedef const struct _jc_javax_rmi_PortableRemoteObject$vtable	_jc_javax_rmi_PortableRemoteObject$vtable;
typedef const struct _jc_javax_rmi_PortableRemoteObject$vtype	_jc_javax_rmi_PortableRemoteObject$vtype;

// Class fields structure
struct _jc_javax_rmi_PortableRemoteObject$fields_struct {
	struct _jc_object	*delegate;
};
extern _jc_javax_rmi_PortableRemoteObject$fields_struct _jc_javax_rmi_PortableRemoteObject$class_fields;

// Constructors
extern void _jc_javax_rmi_PortableRemoteObject$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_rmi_PortableRemoteObject$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_javax_rmi_PortableRemoteObject$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_javax_rmi_PortableRemoteObject$method$connect$64cce43a3a8f81df(_jc_env *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_rmi_PortableRemoteObject$method$exportObject$f24f2fffff6dde7d(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_javax_rmi_PortableRemoteObject$method$narrow$3c78d1e45f465b3b(_jc_env *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_rmi_PortableRemoteObject$method$toStub$eb510defe3584b97(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_rmi_PortableRemoteObject$method$unexportObject$be7fa0efab735c7e(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_rmi_PortableRemoteObject$vmethods {
};

// Vtable
struct _jc_javax_rmi_PortableRemoteObject$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_rmi_PortableRemoteObject$vmethods	javax_rmi_PortableRemoteObject;
};

// Vtype
struct _jc_javax_rmi_PortableRemoteObject$vtype {
	_jc_type			type;
	_jc_javax_rmi_PortableRemoteObject$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_rmi_PortableRemoteObject$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_rmi_PortableRemoteObject$refs {
    _jc_javax_rmi_PortableRemoteObject$sub_refs	javax_rmi_PortableRemoteObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_rmi_PortableRemoteObject$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_rmi_PortableRemoteObject$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_rmi_PortableRemoteObject$sub_nonrefs	javax_rmi_PortableRemoteObject;
};

// Object instance structure
struct _jc_javax_rmi_PortableRemoteObject$object {
	_jc_javax_rmi_PortableRemoteObject$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_rmi_PortableRemoteObject$vtype	*vtype;
	_jc_javax_rmi_PortableRemoteObject$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_rmi_PortableRemoteObject$vtype _jc_javax_rmi_PortableRemoteObject$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_rmi_PortableRemoteObject, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_rmi_PortableRemoteObject$class_object;

#endif	/* _JC_javax_rmi_PortableRemoteObject_H_ */
